package com.lantone.qc.kernel.catalogue.firstpagerecord;

import com.google.common.collect.Lists;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.entity.Diag;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : FIRP0175
 * @Description :主要诊断与出院小结不一致
 * @Author : 胡敬
 * @Date: 2020-03-18 16:17
 */
@Component
public class FIRP0175 extends QCCatalogue {
    List<String> diags = Lists.newArrayList("2型糖尿病");

    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        if (inputInfo.getFirstPageRecordDoc() != null && inputInfo.getLeaveHospitalDoc() != null) {
            Map<String, Object> firstpageStructureMap = inputInfo.getFirstPageRecordDoc().getStructureExtMap();
            //病案首页出院诊断
            List<Map<String, String>> dischargeDiag = (List) firstpageStructureMap.get(Content.dischargeDiag);
            //出院小结诊断
            List<Diag> leaveDiags = null;
            if (inputInfo.getLeaveHospitalDoc().getLeaveDiagLabel() != null) {
                leaveDiags = inputInfo.getLeaveHospitalDoc().getLeaveDiagLabel().getDiags();
            }
            if (ListUtil.isEmpty(dischargeDiag) || ListUtil.isEmpty(leaveDiags)) {
                return;
            }
            String firstpageleaveDiag = "";
            for (Map<String, String> diag:dischargeDiag) {
                String diagCategory = diag.get("诊断类别");
                if (StringUtil.isNotBlank(diagCategory) && "主要诊断".equals(diagCategory)){
                    firstpageleaveDiag = diag.get(Content.diagnoseName);
                    break;
                }
            }
            String leaveDiag = leaveDiags.get(0).getHospitalDiagName();
            //判断是否有2型糖尿病这种病如果没有，把疾病前的数字去掉
            if (!diags.contains(leaveDiag)) {
                leaveDiag = leaveDiag.replaceAll("^[0-9]", "");
            }
            if (!CatalogueUtil.compareToken(firstpageleaveDiag, leaveDiag)) {
                status.set("-1");
            }

        }
    }
}